**** JEP Replication File
*** Job Training and Job Search Assistance Policies in Developing Countries
*** Carranza and McKenzie


* Set Stata version
version 16.0

** Set directory
clear
if c(username)=="wb200090"{
global maindir "C:/Users/wb200090/OneDrive - WBG/JEPJobSearchTrai/JEPRevision/Replication/"
}
global output "$maindir/output"
sysdir set PLUS "${maindir}/ado"


****************************************************************
********* Figure 1: Unemployment Rates  ************************
****************************************************************

use "$maindir/Data/Figure1UnemploymentRates.dta", clear

gen unemp1=unemployment2022 if unemployment2022>15
gen unemp2=unemployment2022 if unemployment2022<15
gen youth1=youthunemp2022 in 1/20
gen youth2=youthunemp2022 in 21/23

graph hbar (mean) unemp1 unemp2 youth1 youth2, over(country, sort(unemployment2022) descending) graphregion(color(white)) ytitle("Unemployment Rate in 2022 (%)", size(small)) ///
bar(1,color(gs4)) bar(2,color(gs8)) bar(3, color(white) lcolor(black)) bar(4, color(gs14) lcolor(black)) nofill legend(off)
* Add Text to Label Overall and Youth Bars
gr_edit plotregion1.AddTextBox added_text editor 100.6848172228771 31.58175473288615
gr_edit plotregion1.added_text_new = 1
gr_edit plotregion1.added_text_rec = 1
gr_edit plotregion1.added_text[1].style.editstyle  angle(default) size( sztype(relative) val(2.5) allow_pct(1)) color(black) horizontal(left) vertical(middle) margin( gleft( sztype(relative) val(0) allow_pct(1)) gright( sztype(relative) val(0) allow_pct(1)) gtop( sztype(relative) val(0) allow_pct(1)) gbottom( sztype(relative) val(0) allow_pct(1))) linegap( sztype(relative) val(0) allow_pct(1)) drawbox(no) boxmargin( gleft( sztype(relative) val(0) allow_pct(1)) gright( sztype(relative) val(0) allow_pct(1)) gtop( sztype(relative) val(0) allow_pct(1)) gbottom( sztype(relative) val(0) allow_pct(1))) fillcolor(bluishgray) linestyle( width( sztype(relative) val(.2) allow_pct(1)) color(black) pattern(solid) align(inside)) box_alignment(east) editcopy
gr_edit plotregion1.added_text[1].text = {}
gr_edit plotregion1.added_text[1].text.Arrpush Overall Rate

gr_edit plotregion1.AddTextBox added_text editor 97.55158740801026 53.9617489881045
gr_edit plotregion1.added_text_new = 2
gr_edit plotregion1.added_text_rec = 2
gr_edit plotregion1.added_text[2].style.editstyle  angle(default) size( sztype(relative) val(2.5) allow_pct(1)) color(black) horizontal(left) vertical(middle) margin( gleft( sztype(relative) val(0) allow_pct(1)) gright( sztype(relative) val(0) allow_pct(1)) gtop( sztype(relative) val(0) allow_pct(1)) gbottom( sztype(relative) val(0) allow_pct(1))) linegap( sztype(relative) val(0) allow_pct(1)) drawbox(no) boxmargin( gleft( sztype(relative) val(0) allow_pct(1)) gright( sztype(relative) val(0) allow_pct(1)) gtop( sztype(relative) val(0) allow_pct(1)) gbottom( sztype(relative) val(0) allow_pct(1))) fillcolor(bluishgray) linestyle( width( sztype(relative) val(.2) allow_pct(1)) color(black) pattern(solid) align(inside)) box_alignment(east) editcopy
gr_edit plotregion1.added_text[2].text = {}
gr_edit plotregion1.added_text[2].text.Arrpush Youth Rate


graph save "$output/Figure1.gph", replace
graph export "$output/Figure1.png", replace
graph export "$output/Figure1.pdf", replace
graph export "$output/Figure1.eps", replace

************************************************************************
******** Table 1: Main Methods of Finding Jobs *************************
************************************************************************

use "$maindir/Data/Table1jobmethods.dta", clear
local i=1
mat y = J(7,7,.)
foreach var of varlist friendsrelatives directapplication newspaperad internet publicprivateagency other {
	sum `var' if country=="Albania"
	mat y[`i',1]=round(100*r(mean),0.1)
	mat y[7,1]=14653
	sum `var' if country=="Jordan 2012"
	mat y[`i',2]=round(100*r(mean),0.1)
	mat y[7,2]=r(N)
	sum `var' if country=="Mexico 2014"
	mat y[`i',3]=round(100*r(mean), 0.1)
	mat y[7,3]=r(N)
	sum `var' if country=="Morocco 2010"
	mat y[`i',4]=round(100*r(mean), 0.1)
	mat y[7,4]=r(N)
	sum `var' if country=="Romania"
	mat y[`i',5]=round(100*r(mean), 0.1)
	mat y[7,5]=36542
	sum `var' if country=="Sierra Leone 2014"
	mat y[`i',6]=round(100*r(mean), 0.1)
	mat y[7,6]=r(N)
	sum `var' if country=="Turkey 2011"
	mat y[`i',7]=round(100*r(mean),0.1)	
	mat y[7,7]=r(N)
local i=`i'+1	
}

mat colnames y = "Albania" "Jordan" "Mexico" "Morocco" "Romania" "Sierra Leone" "Turkey"
mat rownames y = "Friends and Relatives" "Direct Application" "Newspaper ads" "Internet" "Public or Private Agency" "Other" "Sample Size"
mat2txt, matrix(y) saving("$output/Table1.xls") replace

*** note: Albania and Romania raw data not available. 
*** Calculations made from tabulations provided by ILO
*** Albania  
  * Friends and Relatives: 4226*100/14653
  * Direct application to Employers: 7722*100/14653
  * Newspaper ads: 76*100/14653
  * Internet: 49*100/14653
  * Public or Private Employment Agency: 100*(1224+63+44)/14653
  * Other: 100*(533+716)/14653
*** Romania
  * Friends and Relatives: 13606*100/36542
  * Direct application to Employers: 13299*100/36542
  * Newspaper ads and internet: 100*5735/36542
  * Public or private employment agency: 100*(605+300)/36542
  * Other: 100*(220+835+1618+324)/36542
  
*****************************************************************************************************
****** Figure 2: Percent of Employers saying they struggle to find talent with skills they need *****
*****************************************************************************************************

use "$maindir/Data/Figure2ManpowerData.dta", clear
gen percent1=percent in 1/12
gen percent2=percent in 13/14
label var percent "Percent of Firms"
gen rank1=_n
graph hbar percent1 percent2, over(country, sort(rank1)) graphregion(color(white)) ytitle("Percent of firms reporting difficulty finding talent") ysc(r(100)) ytick(0(20)100) ylabel(0(20)100) nofill legend(off) bar(1,color(gs4)) bar(2,color(gs8))
	graph save "$output/Figure2.gph", replace
	graph export "$output/Figure2.png", replace
	graph export "$output/Figure2.pdf", replace
    graph export "$output/Figure2.eps", replace
	
	
***************************************************************************************************
*** Figure 3: Impacts of Vocational Training Programs *********************************************
***************************************************************************************************

* See Data Sources for source of each estimate plotted

* Set graph options
global graph_opts title(, justification(center) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid)  yscale(noline) xscale(noline) legend(region(lc(none) fc(none)))


*** Impact on Employment
cap mat drop Impacts
** Dominican Republic - Acevedo et al. (2020)
* Women
mat a = [1.0,-4.8,6.9,1]
* Men
mat b = [-1.6,-8.9,5.7,2]
** Colombia - Attanasio  et al. (2011)
* Women
mat c = [6.8,2.3,9.1,1]
* Men
mat d = [1.3,-4.4,7.0,2]
** Cote d'Ivoire - Crepon and Premand (2021)
* Pooled Men and Women (87% Male)
mat e = [1.3,0.2,2.4,3]
** Ghana - Hardy et al. (2019)
mat f = [-2.9,-6.2,0.4,3]
** Turkey - Hirschleifer et al. (2016)
mat g = [2.0,-0.5,4.4,3]

mat Impacts = nullmat(Impacts) \ a \ b \ c \ d \ e \ f \ g
mat colnames Impacts = "b" "ll" "ul" "type"
matlist Impacts
	clear
svmat Impacts , names(col)	
qui gen n = _n
replace n=n+1 if n>2
replace n=n+1 if n>5
replace n=n+1 if n>7
replace n=n+1 if n>9

* Graph, adding vertical line for meta-analysis pooled impact of 4.0
	tw ///
		(rcap ll ul n if type == 1 , hor lc(red)) ///
		(scatter n b if type == 1 , mc(black)) ///
		(rcap ll ul n if type == 2 , hor lc(ebblue)) ///
		(scatter n b if type == 2 , mc(black)) ///
		(rcap ll ul n if type == 3 , hor lc(black)) ///
		(scatter n b if type == 3 , mc(black)), ///		
        ${graph_opts} ///
        ytit(" ") ///
        xline(0 , lc(gs12) lp(dash))  ///
		xline(4, lc(gs4)) ///
		xtitle("Percentage Point Increase in Employment") ///
		ylabel( 1 "Dominican Republic Women" 2 "Dominican Republic Men" 4 "Colombia Women" 5 "Colombia Men" 7 "Cote d'Ivoire" ///
		9 "Ghana" 11 "Turkey")  ///
		title("Impact on Employment") ///
		legend(off)
		graph save "$output/Emp1.gph", replace
		
* Impact on Labor Earnings
cap mat drop Impacts
** Dominican Republic - Acevedo et al. (2020)
* Women
mat a = [1.8,-14.9,18.5,1]
* Men
mat b = [-9.6,-25.3,6.1,2]
** Colombia - Attanasio  et al. (2011)
* Women
mat c = [19.6,5.5,30.3,1]
* Men
mat d = [5.2,-4.3,14.6,2]
** Cote d'Ivoire - Crepon and Premand (2021)
* Pooled Men and Women (87% Male)
mat e = [16.9,3.8,30.1,3]
** Ghana - Hardy et al. (2019)
mat f = [-12.9,-25.4,-0.4,3]
** Turkey - Hirschleifer et al. (2016)
mat g = [5.8,-2.3,13.8,3]

mat Impacts = nullmat(Impacts) \ a \ b \ c \ d \ e \ f \ g
mat colnames Impacts = "b" "ll" "ul" "type"
matlist Impacts
	clear
svmat Impacts , names(col)	
qui gen n = _n
replace n=n+1 if n>2
replace n=n+1 if n>5
replace n=n+1 if n>7
replace n=n+1 if n>9

* Graph, adding vertical line for meta-analysis pooled impact of 8.2
	tw ///
		(rcap ll ul n if type == 1 , hor lc(red)) ///
		(scatter n b if type == 1 , mc(black)) ///
		(rcap ll ul n if type == 2 , hor lc(ebblue)) ///
		(scatter n b if type == 2 , mc(black)) ///
		(rcap ll ul n if type == 3 , hor lc(black)) ///
		(scatter n b if type == 3 , mc(black)), ///		
        ${graph_opts} ///
        ytit(" ") ///
        xline(0 , lc(gs12) lp(dash))  ///
		xline(8.2, lc(gs4)) ///
		xtitle("Impact on Labor Earnings") ///
		ylabel( 1 "Dominican Republic Women" 2 "Dominican Republic Men" 4 "Colombia Women" 5 "Colombia Men" 7 "Cote d'Ivoire" ///
		9 "Ghana" 11 "Turkey")  ///
		title("Percent Increase in Earnings") ///
		legend(off)
		graph save "$output/Emp2.gph", replace

		
*** Combine the Two
graph combine "$output/Emp1.gph" "$output/Emp2.gph", col(1) graphregion(color(white))
graph save "$output/Figure3.gph", replace
graph export "$output/Figure3.png", replace
graph export "$output/Figure3.pdf", replace
graph export "$output/Figure3.eps", replace


*************************************************************************************************
**** Figure 4: Impacts of Job Search Assistance Programs ****************************************
*************************************************************************************************

* See Data Sources for source of each estimate plotted

*** Impact on Employment
cap mat drop Impacts
** Carranza et al. (2022) - Signaling: South Africa
mat a= [5.200, 2.848, 7.552,3]
** Bassi and Nasamba (2022) Signaling: Uganda
mat b = [2.900,	-2.784,	8.584,3]
** Abebe et al. (2021) - Workshop signaling: Ethiopia (c), short run
* Long run
mat c = [2.900,-3.372, 9.172, 1]
* Short run
mat d = [2.100,-3.976, 8.176, 3]
*SUBTITLE: SKILL SIGNALING INTERVENTION
mat e = [., ., ., 3]
** Abebe et al. (2021) - Transport subsidy
* Long run
mat f = [-5.800,-12.660, 1.060,1]
* Short run
mat g = [3.700,-1.984, 9.384,3]
** Banerjee and Sequeira (2020)	Transport subsidy: South Africa
mat h = [-0.500,-8.536,7.536,3]
** Franklin (2017) Transport subsidy: Ethiopia (a)
mat i = [6.700,0.036,13.364,3]
*SUBTITLE: TRANSPORT SUBSIDY INTERVENTION
mat j = [., ., ., 3]

mat Impacts = nullmat(Impacts) \ a \ b \ c \ d \ e \ f \ g \ h \ i \ j 
mat colnames Impacts = "b" "ll" "ul" "type"
matlist Impacts
	clear
svmat Impacts , names(col)	
qui gen n = _n
matlist Impacts

	tw ///
		(rcap ll ul n if type == 1 , hor lc(red)) ///
		(scatter n b if type == 1 , mc(black)) ///
		(rcap ll ul n if type == 2 , hor lc(black)) ///
		(scatter n b if type == 2 , mc(black)) ///
		(rcap ll ul n if type == 3 , hor lc(ebblue)) ///sta
		(scatter n b if type == 3 , mc(black)), ///		
        ${graph_opts} ///
        ytit(" ") ///
        xline(0 , lc(gs12) lp(dash))  ///
		xtitle("Percentage Point Increase in Employment", size(small)) ///
		ylabel( 1 "South Africa" 2 "Uganda" 3 "Ethiopia(b), long run" 4 "Ethiopia(b)" 5 "SKILL SIGNALING INTERVENTIONS:" 6 "Ethiopia(b), long run" 7 "Ethiopia(b)" 8 "South Africa" 9 "Ethiopia(a)" 10 "TRANSPORT SUBSIDY INTERVENTIONS:" ) ///
		title("Impact on Employment") ///
		legend(off)
	     graph save "$output/Fig4a.gph", replace
		

*** Impact on Earnings
cap mat drop Impacts
** Carranza et al. (2022) - Signaling: South Africa
mat a = [33.700, 19.196, 48.204, 3]
** Bassi and Nasamba (2022) Signaling: Uganda
mat b = [7.881,	-5.407,	21.169, 3]
** Abebe et al. (2021) - Workshop signaling: Ethiopia (c), short run
* Long run
mat c= [24.611,	5.059,	44.163, 1]
* Short run
mat d = [0.455,-16.956, 17.866, 3]
*SUBTITLE: SKILL SIGNALING INTERVENTION
mat e = [., ., ., 3]
** Abebe et al. (2021) - Transport subsidy
* Long run
mat f = [2.541,	-13.946, 19.027, 1]
* Short run
mat g = [8.912,-8.021, 25.845, 3]
** Banerjee and Sequeira (2020)	Transport subsidy: South Africa
mat h = [-5.209,-17.721, 7.302, 3]
** Franklin (2017) Transport subsidy: Ethiopia (a)
mat i = [5.100, -12.148, 22.34, 3]
*SUBTITLE: TRANSPORT SUBSIDY INTERVENTION
mat j = [., ., ., 3]

mat Impacts = nullmat(Impacts) \ a \ b \ c \ d \ e \ f \ g \ h \ i \ j
mat colnames Impacts = "b" "ll" "ul" "type"
matlist Impacts
	clear
svmat Impacts , names(col)	
qui gen n = _n
matlist Impacts

	tw ///
		(rcap ll ul n if type == 1 , hor lc(red)) ///
		(scatter n b if type == 1 , mc(black)) ///
		(rcap ll ul n if type == 2 , hor lc(black)) ///
		(scatter n b if type == 2 , mc(black)) ///
		(rcap ll ul n if type == 3 , hor lc(ebblue)) ///sta
		(scatter n b if type == 3 , mc(black)), ///		
        ${graph_opts} ///
        ytit(" ") ///
        xline(0 , lc(gs12) lp(dash))  ///
		xtitle("Impact on Labor Earnings", size(small)) ///
		ylabel( 1 "South Africa" 2 "Uganda"	3 "Ethiopia(b), long run" 4 "Ethiopia(b)" 5 "SKILL SIGNALING INTERVENTIONS:"	6 "Ethiopia(b), long run" 7 "Ethiopia(b)" 8  "South Africa" 9  "Ethiopia(a)" 10 "TRANSPORT SUBSIDY INTERVENTIONS:" ) ///
		title("Percent increase in Earnings") ///
		legend(off)
		graph save "$output/Fig4b.gph", replace
		
graph combine "$output/Fig4a.gph" "$output/Fig4b.gph", rows(2) cols(1) graphregion(color(white))
graph save "$output/Figure4.gph", replace
graph export "$output/Figure4.png", replace
graph export "$output/Figure4.pdf", replace
graph export "$output/Figure4.eps", replace


***********************************************************************
*** Figure 5: Impacts of Online Job Search Interventions   ************
***********************************************************************
* See Data Sources for source of each estimate plotted

cap mat drop Online
** South Africa - Wheeler at al. (2022)
mat a = [6.9,2.2,11.6,1]
** Mozambique - Jones and Sen (2022)
* Biscate
mat b = [-1,-4.9,2.9,1]
* Emprego
mat c = [0,-3.9,3.9,1]
** India - Kelley et al. (2020)
* Basic
mat d = [-9.2,-13.5,-4.9,1]
* Priority
mat e = [-4.8,-8.9,-0.7,1]
** India - Chakravorty et al. (forthcoming)
mat f = [-3.9,-7.6,-0.2,1]
** India - Alfridi et al. 
* Wives
mat g = [-1.3,-6.2,3.6,1]
* Husbands
mat h = [1.2,-2.3,4.7,1]

mat Online = nullmat(Online) \ a \ b \ c \ d \ e \ f \ g \ h
mat colnames Online = "b" "ll" "ul" "type"
matlist Online
	clear
svmat Online , names(col)	
qui gen n = _n

	tw ///
		(rcap ll ul n if type == 1 , hor lc(ebblue)) ///
		(scatter n b if type == 1 , mc(black)) ///
		(rcap ll ul n if type == 3 , hor lc(black)) ///
		(scatter n b if type == 3 , mc(black)), ///		
        ${graph_opts} ///
        ytit(" ") ///
        xline(0 , lc(gs12) lp(dash))  ///
		xtitle("Percentage Point Increase in Employment") ///
		ylabel( 1 "South Africa: LinkedIn" 2 "Mozambique: Biscate" 3 "Mozambique: Emprego" 4 "India: Basic JobShikari" 5 "India: Priority JobShikari" ///
		6 "India: YuvaSampark" 7 "India: Helpersnearme for wives"  ///
		8 "India: Helpersnearme for husbands") ///
		legend(off)
	graph save "$output/Figure5.gph", replace
	graph export "$output/Figure5.png", replace
    graph export "$output/Figure5.pdf", replace
    graph export "$output/Figure5.eps", replace