**** JEP Replication File
*** Job Training and Job Search Assistance Policies in Developing Countries
*** Carranza and McKenzie

**** Construction of file "Table1jobmethods.dta" from source data 
*** This file uses raw data files from public use microdata to extract variables used in Table 1
*** Data sources document provides details of how these raw files can be obtained
*** Note that Romania and Albania raw data are not publicly available, and use cross-tabs provided by Yves Perardel of the ILO

* Set Stata version
version 16.0

** Set directory
clear
if c(username)=="wb200090"{
global maindir "C:/Users/wb200090/OneDrive - WBG/JEPJobSearchTrai/JEPRevision/Replication/Data"
}


**** Extract data 
* Sierra Leone
use "$maindir/Raw/SierraLeone2014/merged A to J de-ID.dta", clear

drop if D_7==.
gen country="Sierra Leone 2014"
gen female=A_5==2
label var female "Respondent is Female"
gen publicprivateagency=D_7==1
label var publicprivateagency "Public or Private Employment Agency"
gen directapplication=D_7==2|D_7==3
label var directapplication "Directly Applied with Employer or went to Work Site"
gen newspaperad=D_7==4 
label var newspaperad "Answered Newspaper Advertisement"
gen friendsrelatives=D_7==5
label var friendsrelatives "Through Friends or Relatives"
gen internet=0
label var internet "Through internet portal"
gen other=D_7>=6 & D_7<=9
label var other "Other"

keep country female publicprivateagency-other
save "$maindir/Raw/SierraLeone2014/SierraLeoneExtract.dta", replace

* Jordan NOW
use "$maindir/Raw/JordanNOW/jndata_puf.dta", clear 
drop if e1_c12a==.
gen country="Jordan 2012"
gen female=b_b2gender==0
label var female "Respondent is female"
gen publicprivateagency=e1_c12a==4|e1_c12a==5
label var publicprivateagency "Public or Private Employment Agency"
gen directapplication=e1_c12a==1
label var directapplication "Directly Applied with Employer or went to Work Site"
gen newspaperad=e1_c12a==6
label var newspaperad "Answered Newspaper Advertisement"
gen friendsrelatives=e1_c12a==2|e1_c12a==3
label var friendsrelatives "Through Friends or Relatives"
gen internet=e1_c12a==7
label var internet "Through internet portal"
gen other=e1_c12a==8
label var other "Other"
keep country female publicprivateagency-other
save "$maindir/Raw/JordanNOW/JordanExtract.dta", replace

* Morocco 
use "$maindir/Raw/Morocco/youth_file.dta", clear
gen country="Morocco 2010"
gen female=sex==2
label var female "Respondent is female"
drop if t3q10a==.
gen publicprivateagency=t3q10a==1|t3q10b==1|t3q10o==1
label var publicprivateagency "Public or Private Employment Agency"
gen directapplication=t3q10h==1|t3q10i==1|t3q10d==1|t3q10j==1
label var directapplication "Directly Applied with Employer or went to Work Site"
gen newspaperad=t3q10f==1
label var newspaperad "Answered Newspaper Advertisement"
gen friendsrelatives=t3q10g==1|t3q10p==1
label var friendsrelatives "Through Friends or Relatives"
gen internet=t3q10m==1|t3q10n==1
label var internet "Through internet portal"
gen other=t3q10e==1|t3q10k==1|t3q10l==1|t3q10q==1
label var other "Other"
keep country female publicprivateagency-other
save "$maindir/Raw/Morocco/MoroccoExtract.dta", replace


* Turkey
use "$maindir/Raw/Turkey/TurkeyPublicUseData.dta", clear
gen country="Turkey 2011"
gen female=MM_female
label var female "Respondent is female" 
drop if BB_C76==.
gen publicprivateagency=BB_C76==3|BB_C76==4
label var publicprivateagency "Public or Private Employment Agency"
gen directapplication=BB_C76==1
label var directapplication "Directly Applied with Employer or went to Work Site"
gen newspaperad=BB_C76==5
label var newspaperad "Answered Newspaper Advertisement"
gen friendsrelatives=BB_C76==2
label var friendsrelatives "Through Friends or Relatives"
gen internet=BB_C76==6
label var internet "Through internet portal"
gen other=BB_C76==98|BB_C76==99
label var other "Other"
keep country female publicprivateagency-other
save "$maindir/Raw/Turkey/TurkeyExtract.dta", replace


* Mexico
* merge sociodemographic and labor files together to get sex and method of finding job
use "$maindir/Raw/MexicoENEO/sdemt114.dta", clear
gen idnum=CD_A+ENT+CON+UPM+D_SEM+N_PRO_VIV+N_HOG+PER+N_REN
distinct idnum
keep idnum SEX
sort idnum
save "$maindir/Raw/MexicoENEO/gender.dta", replace
use "$maindir/Raw/MexicoENEO/coetl114.dta", clear
gen idnum=CD_A+ENT+CON+UPM+D_SEM+N_PRO_VIV+N_HOG+PER+N_REN
distinct idnum
sort idnum
merge idnum using "$maindir/Raw/MexicoENEO/gender.dta"
tab _merge
keep if _merge==3

gen country="Mexico 2014"
gen female=SEX=="2"
label var female "Respondent is female" 
*** Also get data on reason aren't looking for work (reported in text only)
tab P2G2
* categories 02 and 05 are lack of jobs (55+1203), category 03 is lack of skills and experience (271)
destring P3N, force replace
drop if P3N==.
gen publicprivateagency=P3N==2|P3N==3|P3N==4
label var publicprivateagency "Public or Private Employment Agency"
gen directapplication=P3N==1|P3N==9
label var directapplication "Directly Applied with Employer or went to Work Site"
gen newspaperad=P3N==7
label var newspaperad "Answered Newspaper Advertisement"
gen friendsrelatives=P3N==8
label var friendsrelatives "Through Friends or Relatives"
gen internet=P3N==6
label var internet "Through internet portal"
gen other=P3N==10|P3N==5|P3N==99
label var other "Other"
keep country female publicprivateagency-other
save "$maindir/Raw/MexicoENEO/MexicoExtract.dta", replace

*** Combine datasets together and create table
use "$maindir/Raw/JordanNOW/JordanExtract.dta", clear
append using "$maindir/Raw/MexicoENEO/MexicoExtract.dta"
append using "$maindir/Raw/Morocco/MoroccoExtract.dta"
append using "$maindir/Raw/SierraLeone2014/SierraLeoneExtract.dta"
append using "$maindir/Raw/Turkey/TurkeyExtract.dta"

** Add in other countries
set obs 123348

replace country = "Albania" in 123347
replace country = "Romania" in 123348

replace friendsrelatives=4226/14653 if country=="Albania"
replace friendsrelatives=13606/36542 if country=="Romania"
replace directapplication=7722/14653 if country=="Albania"
replace directapplication=13299/36542 if country=="Romania"
replace newspaperad=76/14653 if country=="Albania"
replace newspaperad=5735/36542 if country=="Romania"
replace internet=49/14653 if country=="Albania"
replace publicprivateagency=(1224+63+44)/14653 if country=="Albania"
replace publicprivateagency=(605+300)/36542 if country=="Romania"
replace other=(533+716)/14653 if country=="Albania"
replace other=(220+835+1618+324)/36542 if country=="Romania"

*** Albania  
  * Friends and Relatives: 4226*100/14653
  * Direct application to Employers: 7722*100/14653
  * Newspaper ads: 76*100/14653
  * Internet: 49*100/14653
  * Public or Private Employment Agency: 100*(1224+63+44)/14653
  * Other: 100*(533+716)/14653
*** Romania
  * Friends and Relatives: 13606*100/36542
  * Direct application to Employers: 13299*100/36542
  * Newspaper ads and internet: 100*5735/36542
  * Public or private employment agency: 100*(605+300)/36542
  * Other: 100*(220+835+1618+324)/36542


save "$maindir/Data/Table1jobmethods.dta", replace



